==> qtjambi-qt3drender-6.2.7-sources.jar: io/qt/qt3d/render/QTextureWrapMode.java <==
package io.qt.qt3d.render;


/**
 * <p>Defines the wrap mode a Qt3DRender::QAbstractTexture should apply to a texture</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html">Qt3DRender::QTextureWrapMode</a></p>
 */
public class QTextureWrapMode extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureWrapMode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#WrapMode-enum">Qt3DRender::QTextureWrapMode::WrapMode</a></p>
     */
    public enum WrapMode implements io.qt.QtEnumerator {
        Repeat(10497),
        MirroredRepeat(33648),
        ClampToEdge(33071),
        ClampToBorder(33069);

        private WrapMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static WrapMode resolve(int value) {
            switch (value) {
            case 10497: return Repeat;
            case 33648: return MirroredRepeat;
            case 33071: return ClampToEdge;
            case 33069: return ClampToBorder;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#x-prop">Qt3DRender::QTextureWrapMode::xChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="x")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> xChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#y-prop">Qt3DRender::QTextureWrapMode::yChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="y")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> yChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#z-prop">Qt3DRender::QTextureWrapMode::zChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="z")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> zChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode) {
        this(wrapMode, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}</p>
     * <p>with: </p><ul>
     * <li><code>wrapMode = io.qt.qt3d.render.QTextureWrapMode.WrapMode.ClampToEdge</code></li>
     * <li><code>parent = null</code></li>
     * </ul>
     */
    public QTextureWrapMode() {
        this(io.qt.qt3d.render.QTextureWrapMode.WrapMode.ClampToEdge, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#QTextureWrapMode-1">Qt3DRender::QTextureWrapMode::QTextureWrapMode(Qt3DRender::QTextureWrapMode::WrapMode,QObject*)</a></p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, wrapMode, parent);
    }
    
    private native static void initialize_native(QTextureWrapMode instance, io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z) {
        this(x, y, z, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#QTextureWrapMode-1">Qt3DRender::QTextureWrapMode::QTextureWrapMode(Qt3DRender::QTextureWrapMode::WrapMode,Qt3DRender::QTextureWrapMode::WrapMode,Qt3DRender::QTextureWrapMode::WrapMode,QObject*)</a></p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, x, y, z, parent);
    }
    
    private native static void initialize_native(QTextureWrapMode instance, io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setX">Qt3DRender::QTextureWrapMode::setX(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="x")
    public final void setX(io.qt.qt3d.render.QTextureWrapMode.WrapMode x){
        setX_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), x.value());
    }
    
    private native void setX_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setY">Qt3DRender::QTextureWrapMode::setY(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="y")
    public final void setY(io.qt.qt3d.render.QTextureWrapMode.WrapMode y){
        setY_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), y.value());
    }
    
    private native void setY_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int y);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setZ">Qt3DRender::QTextureWrapMode::setZ(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="z")
    public final void setZ(io.qt.qt3d.render.QTextureWrapMode.WrapMode z){
        setZ_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), z.value());
    }
    
    private native void setZ_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int z);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#x-prop">Qt3DRender::QTextureWrapMode::x()const</a></p>
     */
    @io.qt.QtPropertyReader(name="x")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode x(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int x_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#y-prop">Qt3DRender::QTextureWrapMode::y()const</a></p>
     */
    @io.qt.QtPropertyReader(name="y")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode y(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int y_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#z-prop">Qt3DRender::QTextureWrapMode::z()const</a></p>
     */
    @io.qt.QtPropertyReader(name="z")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode z(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int z_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureWrapMode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureWrapMode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureWrapMode instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.10-sources.jar: io/qt/qt3d/render/QTextureWrapMode.java <==
package io.qt.qt3d.render;


/**
 * <p>Defines the wrap mode a Qt3DRender::QAbstractTexture should apply to a texture</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html">Qt3DRender::QTextureWrapMode</a></p>
 */
public class QTextureWrapMode extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureWrapMode.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#WrapMode-enum">Qt3DRender::QTextureWrapMode::WrapMode</a></p>
     */
    public enum WrapMode implements io.qt.QtEnumerator {
        Repeat(10497),
        MirroredRepeat(33648),
        ClampToEdge(33071),
        ClampToBorder(33069);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private WrapMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static WrapMode resolve(int value) {
            switch (value) {
            case 10497: return Repeat;
            case 33648: return MirroredRepeat;
            case 33071: return ClampToEdge;
            case 33069: return ClampToBorder;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#x-prop">Qt3DRender::QTextureWrapMode::xChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="x")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> xChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#y-prop">Qt3DRender::QTextureWrapMode::yChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="y")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> yChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#z-prop">Qt3DRender::QTextureWrapMode::zChanged(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="z")
    public final Signal1<io.qt.qt3d.render.QTextureWrapMode.WrapMode> zChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode) {
        this(wrapMode, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}</p>
     * <p>with: </p><ul>
     * <li><code>wrapMode = io.qt.qt3d.render.QTextureWrapMode.WrapMode.ClampToEdge</code></li>
     * <li><code>parent = null</code></li>
     * </ul>
     */
    public QTextureWrapMode() {
        this(io.qt.qt3d.render.QTextureWrapMode.WrapMode.ClampToEdge, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#QTextureWrapMode-1">Qt3DRender::QTextureWrapMode::QTextureWrapMode(Qt3DRender::QTextureWrapMode::WrapMode,QObject*)</a></p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, wrapMode, parent);
    }
    
    private native static void initialize_native(QTextureWrapMode instance, io.qt.qt3d.render.QTextureWrapMode.WrapMode wrapMode, io.qt.core.QObject parent);
    
    /**
     * <p>Overloaded constructor for {@link #QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.qt3d.render.QTextureWrapMode.WrapMode, io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z) {
        this(x, y, z, (io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#QTextureWrapMode-1">Qt3DRender::QTextureWrapMode::QTextureWrapMode(Qt3DRender::QTextureWrapMode::WrapMode,Qt3DRender::QTextureWrapMode::WrapMode,Qt3DRender::QTextureWrapMode::WrapMode,QObject*)</a></p>
     */
    public QTextureWrapMode(io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z, io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, x, y, z, parent);
    }
    
    private native static void initialize_native(QTextureWrapMode instance, io.qt.qt3d.render.QTextureWrapMode.WrapMode x, io.qt.qt3d.render.QTextureWrapMode.WrapMode y, io.qt.qt3d.render.QTextureWrapMode.WrapMode z, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setX">Qt3DRender::QTextureWrapMode::setX(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="x")
    public final void setX(io.qt.qt3d.render.QTextureWrapMode.WrapMode x){
        setX_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), x.value());
    }
    
    private native void setX_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setY">Qt3DRender::QTextureWrapMode::setY(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="y")
    public final void setY(io.qt.qt3d.render.QTextureWrapMode.WrapMode y){
        setY_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), y.value());
    }
    
    private native void setY_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int y);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#setZ">Qt3DRender::QTextureWrapMode::setZ(Qt3DRender::QTextureWrapMode::WrapMode)</a></p>
     */
    @io.qt.QtPropertyWriter(name="z")
    public final void setZ(io.qt.qt3d.render.QTextureWrapMode.WrapMode z){
        setZ_native_Qt3DRender_QTextureWrapMode_WrapMode(QtJambi_LibraryUtilities.internal.nativeId(this), z.value());
    }
    
    private native void setZ_native_Qt3DRender_QTextureWrapMode_WrapMode(long __this__nativeId, int z);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#x-prop">Qt3DRender::QTextureWrapMode::x()const</a></p>
     */
    @io.qt.QtPropertyReader(name="x")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode x(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(x_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int x_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#y-prop">Qt3DRender::QTextureWrapMode::y()const</a></p>
     */
    @io.qt.QtPropertyReader(name="y")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode y(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(y_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int y_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexturewrapmode.html#z-prop">Qt3DRender::QTextureWrapMode::z()const</a></p>
     */
    @io.qt.QtPropertyReader(name="z")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QTextureWrapMode.WrapMode z(){
        return io.qt.qt3d.render.QTextureWrapMode.WrapMode.resolve(z_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int z_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTextureWrapMode(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTextureWrapMode(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTextureWrapMode instance, QDeclarativeConstructor constructor);
    
}
